import time
import rti.connextdds as dds
from VideoData import VideoData  # IDL로 생성된 Python 모듈

def publish_video(file_path, domain_id=0):
    qos_provider = dds.QosProvider("QOS_PROFILES.xml")
    participant = dds.DomainParticipant(domain_id, qos_provider.participant_qos)
    topic = dds.Topic(participant, "Video", VideoData)
    writer = dds.DataWriter(participant.implicit_publisher, topic, qos_provider.datawriter_qos_from_profile("MyLibrary::MyProfile"))

    # 구독자 연결 및 시간 측정 변수 초기화
    start_time = None
    end_time = None

    # 구독자 연결 확인 함수
    def is_subscriber_connected():
        return writer.publication_matched_status.current_count > 0

    # 구독자가 연결될 때까지 대기
    while not is_subscriber_connected():
        pass

    # 구독자 연결 후 시작 시간 기록
    start_time = time.time()
    print("구독자 연결됨, 파일 전송 시작")

    chunk_id = 0  # 데이터 조각 ID 초기화
    with open(file_path, "rb") as video_file:
        while True:
            data_chunk = video_file.read(1024)  # 1024 바이트씩 읽기
            if not data_chunk:
                break
            video_data = VideoData(chunk_id=chunk_id, data=list(data_chunk))  # chunk_id 필드 추가
            writer.write(video_data)
            print(f"Sent chunk {chunk_id}")
            chunk_id += 1

    # 전송 완료 후 완료 시간 기록
    end_time = time.time()
    total_time = end_time - start_time
    print(f"파일 전송 완료! 전송에 걸린 총 시간: {total_time:.2f} 초")

if __name__ == "__main__":
    video_path = "C:\\Users\\MDCL\\Desktop\\video\\road_video.mp4"
    publish_video(video_path)
