import rti.connextdds as dds
from VideoData import VideoData  # IDL로 생성된 Python 모듈

def receive_video(output_path, domain_id=0):
    qos_provider = dds.QosProvider("QOS_PROFILES.xml")
    participant = dds.DomainParticipant(domain_id, qos_provider.participant_qos)
    topic = dds.Topic(participant, "Video", VideoData)
    reader = dds.DataReader(participant.implicit_subscriber, topic, qos_provider.datareader_qos_from_profile("MyLibrary::MyProfile"))

    expected_chunk_id = 0  # 수신할 예상 데이터 조각 ID 초기화
    with open(output_path, "wb") as video_file:
        while True:
            samples = reader.take()
            for sample in samples:
                if sample.info.valid:
                    # 현재 chunk_id가 예상한 chunk_id와 일치하는지 확인
                    if sample.data.chunk_id == expected_chunk_id:
                        video_file.write(bytes(sample.data.data))
                        print(f"Received chunk {expected_chunk_id}")
                        expected_chunk_id += 1
                    else:
                        print(f"Expected chunk {expected_chunk_id}, but received {sample.data.chunk_id}. Waiting for the correct chunk.")

if __name__ == "__main__":
    output_path = "received_video.mp4"
    receive_video(output_path)
